@@ -1,4 +1,6 @@
 import json
+import pickle
+
 import spacy
 
 
@@ -34,7 +36,44 @@ class TextMining:
         Initializes the TextMining module.
         :param standard_model: The standard model to use. Default is 'en_core_web_lg'. To download this model, see https://spacy.io/models/en. If you want to use any other language, please refer to https://spacy.io/models
         """
-        self.nlp = spacy.load(standard_model)
+        self.standard_model = standard_model
+        self.__connect__()
+
+    def __connect__(self):
+        """
+        Internal function to connect to the Spacy model.
+        """
+        self.nlp = spacy.load(self.standard_model)
+
+    def __is_picklable__(self, obj: any) -> bool:
+        """
+        Internal function to determine if the object is pickable.
+        :param obj: The object to check.
+        :return: True or False
+        """
+        try:
+            pickle.dumps(obj)
+            return True
+        except Exception as e:
+            return False
+
+    def __getstate__(self):
+        """
+        Internal function for serialization
+        """
+        state = self.__dict__.copy()
+        for key, val in state.items():
+            if not self.__is_picklable__(val):
+                state[key] = str(val)
+        return state
+
+    def __setstate__(self, state):
+        """
+        Internal function for deserialization
+        :param state: The state to set to the 'self' object of the class
+        """
+        self.__dict__.update(state)
+        self.__connect__()
 
     def get_named_entities(self, text):
         """
